@@ -1,22 +1,31 @@
 #
 # This file is part of Text-Levenshtein-XS
 #
-# This software is copyright (c) 2014 by Nick Logan.
+# This software is copyright (c) 2015 by Nick Logan.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 package Text::Levenshtein::XS;
-$Text::Levenshtein::XS::VERSION = '0.43';
+
 use 5.008;
 use strict;
 use warnings FATAL => 'all';
 require Exporter;
-require XSLoader;
-XSLoader::load('Text::Levenshtein::XS', $Text::Levenshtein::XS::VERSION);
 
 @Text::Levenshtein::XS::ISA       = qw/Exporter/;
 @Text::Levenshtein::XS::EXPORT_OK = qw/distance/;
+$Text::Levenshtein::XS::VERSION   = 0.500;
+
+eval {
+    require XSLoader;
+    XSLoader::load(__PACKAGE__, $Text::Levenshtein::XS::VERSION);
+    1;
+} or do {
+    require DynaLoader;
+    DynaLoader::bootstrap(__PACKAGE__, $Text::Levenshtein::XS::VERSION);
+    sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
+};
 
 
 
@@ -38,7 +47,7 @@ Text::Levenshtein::XS - Calculate edit distance based on insertion, deletion, su
 
 =head1 VERSION
 
-version 0.43
+version 0.500
 
 =head1 SYNOPSIS
 
@@ -109,6 +118,9 @@ Drop in replacement for L<Text::LevenshteinXS>
 
 L<https://github.com/ugexe/Text--Levenshtein--XS>
 
+=for HTML <a href="https://travis-ci.org/ugexe/Text--Levenshtein--XS?branch=release"><img src="https://travis-ci.org/ugexe/Text--Levenshtein--XS.svg?branch=release"></a>
+    <a href='https://coveralls.io/r/ugexe/Text--Levenshtein--XS?branch=release'><img src='https://coveralls.io/repos/ugexe/Text--Levenshtein--XS/badge.png?branch=release' alt='Coverage Status' /></a>
+
 =head1 BUGS
 
 Please report bugs to:
@@ -121,7 +133,7 @@ ugexe <ugexe@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Nick Logan.
+This software is copyright (c) 2015 by Nick Logan.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -134,3 +146,4 @@ __END__
 
 # ABSTRACT: Calculate edit distance based on insertion, deletion, substitution, and transposition
 
+
